"""Phonological feature tables.

After:

    Hayes, B. 2009. Introductory Phonology. John Wiley & Sons.

Hayes' tables 4.7-9 (§4.10) have been combined into a single table
(`universal`), and a smaller table targeting English only (`english`) available
online is also present. The versions used were downloaded online from the
following URL:

    https://linguistics.ucla.edu/people/hayes/120a/Index.htm#features

The tables were created simply by converting Hayes' Excel spreadsheets to CSV
files, parsing them to create Python dictionaries, and then printing them. Code
and CSV files for this process are included in the repository but are not
installed by PyPI.

Hayes uses `0` to indicate a feature is undefined for that phone. Such
specifications are thus treated as zeros.

The features are presented in the simplest possible format: a plus or minus
sign followed by their name.

Please see README.md before submitting bugs or feature requests!
"""


english = {
    "k": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ɡ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "v": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "p": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "f": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "b": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ʍ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "+spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "h": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "+spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ʒ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "z": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "t": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ʃ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "s": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "d": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "θ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ð": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "d͡ʒ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "t͡ʃ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "m": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "w": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "j": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ŋ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "n": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "l": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ɾ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "+tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɹ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɚ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɑ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "+back",
    ],
    "æ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "+front",
        "-back",
    ],
    "ʌ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "ɔ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "o": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ə": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "-back",
        "-tense",
    ],
    "e": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ɛ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
    "u": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ʊ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "i": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ɪ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
}

universal = {
    "ɒ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "+back",
    ],
    "ɑ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "+back",
    ],
    "ɶ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "+front",
        "-back",
    ],
    "a": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "-back",
    ],
    "æ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "+front",
        "-back",
    ],
    "ʌ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "ɔ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "o": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ɤ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ɘ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "-back",
        "+tense",
    ],
    "œ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
    "ə": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "-back",
        "-tense",
    ],
    "e": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ɞ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "-back",
        "-tense",
    ],
    "ø": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ɛ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
    "ɵ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "-back",
        "+tense",
    ],
    "ɯ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "u": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ʊ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "-tense",
    ],
    "ɨ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "-back",
        "+tense",
    ],
    "ʉ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "-back",
        "+tense",
    ],
    "y": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "i": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ʏ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
    "ɪ": [
        "+syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "-tense",
    ],
    "ŋ+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ʟ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "+lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "+lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ɫ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɴ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ʀ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "+trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɲ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ʎ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "+lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ŋ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ŋ˗": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "ʟ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "+lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "ɳ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ʙ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "+trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ɭ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ɺ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "+tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ɻ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɽ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "+tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "r": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "+trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "n": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "m": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "l": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ɾ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "+tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɱ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "+sonorant",
        "-continuant",
        "-approximant",
        "-tap",
        "-trill",
        "+nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ʔ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "+constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ɣ+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "x+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "k+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ɡ+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "k+͡x+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ɡ+͡ɣ+": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ħ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "+back",
    ],
    "ʕ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "+low",
        "-front",
        "+back",
    ],
    "ʁ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "q": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "χ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɢ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɕ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ɉ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ʝ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "c": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ç": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "d͡ʑ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "t͡ɕ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ɣ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ɣ̠ ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "x": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "x̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "k": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "k̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "ɡ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ɡ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "ʑ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ʈ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɖ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɬ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ʐ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɸ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ʂ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "ʒ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "z": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "v": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "t": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ʃ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "s": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "p": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "f": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "d": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "b": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "θ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɮ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ð": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "β": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "d͡ʒ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "d͡z": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "d͡ɮ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "d̠͡ɮ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "t͡ʃ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "t̠͡ɬ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "t͡s": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "t͡ɬ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "t̪͡s̪": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "t̪͡ɬ̪": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "d̪͡z̪": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "d̪͡ɮ̪": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "+lateral",
        "-DORSAL",
    ],
    "ʈ͡ʂ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɖ͡ʐ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "p͡f": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "b͡v": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "p͡ɸ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "b͡β": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "t̪͡θ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "d̪͡ð": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "c͡ç": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "ɉ͡ʝ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
    ],
    "k͡x": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "k̠͡x̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "ɡ͡ɣ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "ɡ̠̠͡ɣ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
    ],
    "q͡χ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɢ͡ʁ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "-high",
        "-low",
        "-front",
        "+back",
    ],
    "ɧ": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "+strident",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "k͡p": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "g͡b": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
    ],
    "p͡t": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "b͡d": [
        "-syllabic",
        "-stress",
        "-long",
        "+consonantal",
        "-sonorant",
        "-continuant",
        "-delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "+anterior",
        "-distributed",
        "+strident",
        "-lateral",
        "-DORSAL",
    ],
    "ɰ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+tense",
    ],
    "ɰ̠": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "w": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ɥ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "j": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "+front",
        "-back",
        "+tense",
    ],
    "ɹ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "+CORONAL",
        "-anterior",
        "+distributed",
        "-strident",
        "-lateral",
        "-DORSAL",
    ],
    "ʋ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "+sonorant",
        "+continuant",
        "+approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "-spread gl",
        "-constr gl",
        "+LABIAL",
        "-round",
        "+labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "ʍ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "+spread gl",
        "-constr gl",
        "+LABIAL",
        "+round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "+DORSAL",
        "+high",
        "-low",
        "-front",
        "+back",
        "+tense",
    ],
    "ɦ": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "+voice",
        "+spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
    "h": [
        "-syllabic",
        "-stress",
        "-long",
        "-consonantal",
        "-sonorant",
        "+continuant",
        "+delayed release",
        "-approximant",
        "-tap",
        "-trill",
        "-nasal",
        "-voice",
        "+spread gl",
        "-constr gl",
        "-LABIAL",
        "-round",
        "-labiodental",
        "-CORONAL",
        "-lateral",
        "-DORSAL",
    ],
}
